@@ -32,14 +32,16 @@ CHASSIS_LIST_FIELD_LABELS = ['UUID', 'Description']
 
 NODE_FIELDS = ['chassis_uuid', 'created_at', 'console_enabled', 'driver',
                'driver_info', 'extra', 'instance_info', 'instance_uuid',
-               'last_error', 'maintenance', 'power_state', 'properties',
-               'provision_state', 'reservation', 'target_power_state',
-               'target_provision_state', 'updated_at', 'uuid']
+               'last_error', 'maintenance', 'maintenance_reason',
+               'power_state', 'properties', 'provision_state', 'reservation',
+               'target_power_state', 'target_provision_state', 'updated_at',
+               'uuid']
 
 NODE_FIELD_LABELS = ['Chassis UUID', 'Created At', 'Console Enabled', 'Driver',
                      'Driver Info', 'Extra', 'Instance Info', 'Instance UUID',
-                     'Last Error', 'Maintenance', 'Power State', 'Properties',
-                     'Provision State', 'Reservation', 'Target Power State',
+                     'Last Error', 'Maintenance', 'Maintenance Reason',
+                     'Power State', 'Properties', 'Provision State',
+                     'Reservation', 'Target Power State',
                      'Target Provision State', 'Updated At', 'UUID']
 
 NODE_LIST_FIELDS = ['uuid', 'instance_uuid', 'power_state',
